%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script to generate simulation data for scan based odometry
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Parameters

% RNG
rng(10)

% Environment Generation/Load Flags
env_gen_flag  = 1;
env_file_name = 'sim_data/sim_env2.png';

% SCAN Generation Settings
% Polar Settings
scan_param.range_count = 1000;
scan_param.angle_count = 400;
scan_param.range_max = 30;
scan_param.range_min = 0;
scan_param.angle_max = pi;
scan_param.angle_min = -pi;
scan_param.scale_dist = 0.5;

% Amplitude Settings
scan_param.obst_ampl = 2;

% Smoothing Settings
scan_param.smooth_mult = 3;
scan_param.sigma_gauss_smooth = 1;

% Noise settings
scan_param.muMeasurementNoiseRange = 0;
scan_param.muMeasurementNoiseAngle = 0;
scan_param.sigmaMeasurementNoiseRange = 0.0001;
scan_param.sigmaMeasurementNoiseAngle = 0.0001;

scan_param.sigma_bg = 0.01; 
scan_param.mu_bg = 0; % Background Noise
scan_param.clutter_prob = 0.0000; 
scan_param.clutter_mag = 1;       % Clutter Probability

% Save to myDatasim.mat in Oxford Robotcar format
scan_param.save_flag = 1;
scan_param.save_filename = 'myDatasim2.mat';

% Filter Settings
[parameters] = get_part_filt_param();

%% Load the motion model

% generate true track
startState = [0;0;0;0];
[trueTrack,parameters.priorMean] = getTrueTrack(parameters,startState);

%% Create/Get the Environment
env_param = track2env_param(trueTrack,1.2,10);
% scatter(trueTrack(1,:),trueTrack(2,:))

track_im = flipud(imgaussfilt(env_param.image_out,5));
track_im = (track_im - min(track_im,[],'all'))/max(track_im,[],'all');
track_im = abs(1-track_im);
imshow(track_im)
env_param = env_param_add_im(env_param,env_file_name);
env_param.env_ds = 0.4; % Only keep this fraction of points at random
% imagesc(255-squeeze(env_param.sim_env(:,:,1)))

%% Generate Scans and Save
tic
getpc_scans(trueTrack,env_param,scan_param,parameters);
toc